package biggests.tables;

import java.awt.*;
import java.awt.event.*;

import javax.swing.table.*;

/**
 * <p>Title: Header for Tables of Functions</p>
 *
 * <p>Description: Defines a header for tables of functions.</p>
 *
 * <p>Copyright:   Copyright (C) 2007  Joana Gonçalves
 *                 This program is free software; you can redistribute
 *                 it and/or modify it under the terms of the GNU General
 *                 Public License as published by the Free Software
 *                 Foundation; either version 3 of the License, or
 *                 any later version.
 *
 *                 This program is distributed in the hope that it will
 *                 be useful, but WITHOUT ANY WARRANTY; without even the
 *                 implied warranty of MERCHANTABILITY or FITNESS FOR A
 *                 PARTICULAR PURPOSE.  See the
 *                 <a href="http://www.gnu.org/licenses/gpl.html">
 *                 GNU General Public License</a> for more details.
 * </p>
 *
 * @author Joana P. Gonçalves
 */

public class TableHeaderFunction extends JTableHeader {
    /**
     *  Overrides <code>JTableHeader</code>'s constructor.<br/>
     *  Constructs a <code>TableHeader</code> with a default
     *  <code>TableColumnModel</code>.
     *
     * @see javax.swing.table.JTableHeader#JTableHeader()
     */
    public TableHeaderFunction() {
        super();
    }

    /**
     *  Overrides <code>JTableHeader</code>'s constructor.<br/>
     *  Constructs a <code>TableHeader</code> which is initialized with
     *  <code>cm</code> as the column model.  If <code>cm</code> is
     *  <code>null</code> this method will initialize the table header
     *  with a default <code>TableColumnModel</code>.
     *
     * @param cm	the column model for the table
     * @see javax.swing.table.JTableHeader#JTableHeader(TableColumnModel cm)
     */
    public TableHeaderFunction(TableColumnModel cm) {
        super(cm);
    }

    /**
     * Overrides <code>JTableHeader</code>'s getToolTipText method.<br/>
     * Allows the renderer's tips to be used if there is text set.
     *
     * @param  event  the location of the event identifies the proper
     *				renderer and, therefore, the proper tip
     * @return the tool tip for this component
     * @see javax.swing.table.JTableHeader#getToolTipText(MouseEvent event)
     */
    public String getToolTipText(MouseEvent event) {
        String tip = null;
        Point p = event.getPoint();
        int colIndex = columnModel.getColumnIndexAtX(p.x);
        if (colIndex == -1) {
            return "";
        }
        int realColumnIndex = columnModel.getColumn(colIndex).getModelIndex();
        if ((realColumnIndex >= 0) &&
            (realColumnIndex < columnModel.getColumnCount())) {
            tip = columnModel.getColumn(realColumnIndex).getHeaderValue().
                  toString();
        } else {
            tip = super.getToolTipText(event);
        }
        return tip;
    }
}
