package biggests.utils;

import de.schlichtherle.io.File;
import java.io.PrintWriter;

/**
 * <p>Title: JVM Info</p>
 *
 * <p>Description: Provides methods to get information about the JVM in
 *                 which this code is being executed.</p>
 *
 * <p>Copyright:   Copyright (C) 2008  Joana P. Gonçalves
 *                 This program is free software; you can redistribute
 *                 it and/or modify it under the terms of the GNU General
 *                 Public License as published by the Free Software
 *                 Foundation; either version 3 of the License, or
 *                 any later version.
 *
 *                 This program is distributed in the hope that it will
 *                 be useful, but WITHOUT ANY WARRANTY; without even the
 *                 implied warranty of MERCHANTABILITY or FITNESS FOR A
 *                 PARTICULAR PURPOSE.  See the
 *                 <a href="http://www.gnu.org/licenses/gpl.html">
 *                 GNU General Public License</a> for more details.
 * </p>
 *
 * @author Joana P. Gonçalves
 */
public class JVMInfo {
    /**
     * The main method.
     *
     * @param args String[]
     */
    public static void main(String[] args) {
        writeJVMBitsToFile();
    }

    /**
     * Writes the number of bits of the JVM to a text file
     * named bits.txt in the current directory. The value
     * written to the text file is either 32 or 64.
     */
    public static void writeJVMBitsToFile(){
        PrintWriter pw = null;
        try {
            File file = new File("bits.txt");
            pw = new PrintWriter(file);
            String bits = System.getProperty("sun.arch.data.model", "?");
            if (bits.equals("64")) {
                pw.print("64");
            } else
            if (bits.equals("32")) {
                pw.print("32");
            } else
            if (bits.equals("?")) {
                // probably sun.arch.data.model isn't available
                // maybe not a Sun JVM?
                // try with the vm.name property
                if (System.getProperty("java.vm.name")
                    .toLowerCase().indexOf("64") >= 0) {
                    pw.print("64");
                } else {
                    // probably 32bit
                    pw.print("32");
                }
            }
        }
        catch (Exception e) {
            System.out.println("Error writing bits to file.");
        }
        finally {
            try {
                if (pw != null) {
                    pw.close();
                }
            }
            catch (Exception ex) {
                System.out.println("Error writing bits to file.");
            }
        }
    }
}
